@@ -7,12 +7,13 @@
 ##' @param size size
 ##' @param x x position
 ##' @param y y position
+##' @param vjust vertical adjustment
 ##' @param ... additional parameter for geom_text
 ##' @return ggplot2 layer
 ##' @export
 ##' @author guangchuang yu
-geom_emoji <- function(alias="rose", color="#67001f", size=120, x=1, y=1, ...) {
-    geom_emoji_(alias, color, size, x, y, ...)
+geom_emoji <- function(alias="rose", color="#67001f", size=120, x=1, y=1, vjust=0.25, ...) {
+    geom_emoji_(alias, color, size, x, y, vjust=vjust, ...)
 
 }
 
@@ -35,7 +36,7 @@ geom_fontawesome <- function(alias="fa-github", color="#67001f", size=120, x=1,
 
 ##' @importFrom ggplot2 geom_text
 ##' @importFrom ggplot2 aes_
-geom_emoji_ <- function(alias, color="#67001f", size=120, x=1, y=1, ..., .fun=emoji, family="OpenSansEmoji") {
+geom_emoji_ <- function(alias, color="#67001f", size=120, x=1, y=1, ..., .fun=emoji, family="EmojiOne") {
     data <- data.frame(x=x, y=y, label=.fun(alias))
     geom_text(aes_(~x, ~y, label=~label), data=data, family=family, color=color, size=size, ...)
 }
